@@ -30,20 +30,29 @@ class RecordMetadataModelView(ModelView):
     can_edit = False
     can_delete = True
     can_view_details = True
-    column_list = ('id', 'version_id', 'updated', 'created',)
-    column_details_list = ('id', 'version_id', 'updated', 'created', 'json')
+    column_list = (
+        "id",
+        "version_id",
+        "updated",
+        "created",
+    )
+    column_details_list = ("id", "version_id", "updated", "created", "json")
     column_labels = dict(
-        id=_('UUID'),
-        version_id=_('Revision'),
-        json=_('JSON'),
+        id=_("UUID"),
+        version_id=_("Revision"),
+        json=_("JSON"),
     )
     column_formatters = dict(
-        version_id=lambda v, c, m, p: m.version_id-1,
+        version_id=lambda v, c, m, p: m.version_id - 1,
         json=lambda v, c, m, p: Markup("<pre>{0}</pre>").format(
-            json.dumps(m.json, indent=2, sort_keys=True))
+            json.dumps(m.json, indent=2, sort_keys=True)
+        ),
     )
-    column_filters = ('created', 'updated', )
-    column_default_sort = ('updated', True)
+    column_filters = (
+        "created",
+        "updated",
+    )
+    column_default_sort = ("updated", True)
     page_size = 25
 
     def delete_model(self, model):
@@ -56,13 +65,15 @@ class RecordMetadataModelView(ModelView):
             db.session.commit()
         except SQLAlchemyError as e:
             if not self.handle_view_exception(e):
-                flash(_('Failed to delete record. %(error)s', error=str(e)),
-                      category='error')
+                flash(
+                    _("Failed to delete record. %(error)s", error=str(e)),
+                    category="error",
+                )
             db.session.rollback()
             return False
         return True
 
+
 record_adminview = dict(
-    modelview=RecordMetadataModelView,
-    model=RecordMetadata,
-    category=_('Records'))
+    modelview=RecordMetadataModelView, model=RecordMetadata, category=_("Records")
+)
